summaryrefslogtreecommitdiff
path: root/png.h
diff options
context:
space:
mode:
authorGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2009-08-22 09:24:15 -0500
committerGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2009-08-22 09:26:42 -0500
commita21c94e3dca1fdfb373d869b4e6cef7810371b9f (patch)
treeaefc7e22600ca1f1ad292afa22917ab9788412e8 /png.h
parent38b92d56e7c6052f38d8ce1e34d4fe4b6e536281 (diff)
downloadlibpng-a21c94e3dca1fdfb373d869b4e6cef7810371b9f.tar.gz
[master] Bump version to libpng-1.2.40beta02
Diffstat (limited to 'png.h')
-rw-r--r--png.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/png.h b/png.h
index 3724dfd11..8e0dfc737 100644
--- a/png.h
+++ b/png.h
@@ -1,6 +1,6 @@
/* png.h - header file for PNG reference library
*
* libpng version 1.2.40beta01 - August 20, 2009
* Copyright (c) 1998-2009 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -10,7 +10,7 @@
* Authors and maintainers:
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
* libpng versions 0.97, January 1998, through 1.2.40beta01 - August 20, 2009: Glenn
* See also "Contributing Authors", below.
*
* Note about libpng version numbers:
@@ -273,7 +273,7 @@
*
* This code is released under the libpng license.
*
* libpng versions 1.2.6, August 15, 2004, through 1.2.40beta01, August 20, 2009, are
* Copyright (c) 2004, 2006-2009 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
* with the following individual added to the list of Contributing Authors:
@@ -385,13 +385,13 @@
* Y2K compliance in libpng:
* =========================
*
- * August 20, 2009
+ * August 22, 2009
*
* Since the PNG Development group is an ad-hoc body, we can't make
* an official declaration.
*
* This is your unofficial assurance that libpng from version 0.71 and
* upward through 1.2.40beta01 are Y2K compliant. It is my belief that earlier
* versions were also Y2K compliant.
*
* Libpng only has three year fields. One is a 2-byte unsigned integer
@@ -447,9 +447,9 @@
*/
/* Version information for png.h - this should match the version in png.c */
-#define PNG_LIBPNG_VER_STRING "1.2.40beta01"
+#define PNG_LIBPNG_VER_STRING "1.2.40beta02"
#define PNG_HEADER_VERSION_STRING \
- " libpng version 1.2.40beta01 - August 20, 2009\n"
+ " libpng version 1.2.40beta02 - August 22, 2009\n"
#define PNG_LIBPNG_VER_SONUM 0
#define PNG_LIBPNG_VER_DLLNUM 13
@@ -462,7 +462,7 @@
* PNG_LIBPNG_VER_STRING, omitting any leading zero:
*/
-#define PNG_LIBPNG_VER_BUILD 01
+#define PNG_LIBPNG_VER_BUILD 02
/* Release Status */
#define PNG_LIBPNG_BUILD_ALPHA 1
@@ -1514,7 +1514,7 @@ struct png_struct_def
/* This triggers a compiler error in png.c, if png.c and png.h
* do not agree upon the version number.
*/
-typedef png_structp version_1_2_40beta01;
+typedef png_structp version_1_2_40beta02;
typedef png_struct FAR * FAR * png_structpp;
@@ -1,6 +1,6 @@
/* png.h - header file for PNG reference library
*
- * libpng version 1.2.40beta01 - August 20, 2009
+ * libpng version 1.2.40beta02 - August 22, 2009
* Copyright (c) 1998-2009 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -10,7 +10,7 @@
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- * libpng versions 0.97, January 1998, through 1.2.40beta01 - August 20, 2009: Glenn
+ * libpng versions 0.97, January 1998, through 1.2.40beta02 - August 22, 2009: Glenn
* See also "Contributing Authors", below.
*
@@ -273,7 +273,7 @@
* This code is released under the libpng license.
*
- * libpng versions 1.2.6, August 15, 2004, through 1.2.40beta01, August 20, 2009, are
+ * libpng versions 1.2.6, August 15, 2004, through 1.2.40beta02, August 22, 2009, are
* Copyright (c) 2004, 2006-2009 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
@@ -385,13 +385,13 @@
*
* This is your unofficial assurance that libpng from version 0.71 and
- * upward through 1.2.40beta01 are Y2K compliant. It is my belief that earlier
+ * upward through 1.2.40beta02 are Y2K compliant. It is my belief that earlier
* versions were also Y2K compliant.
*